#include <qsciabstractapis.h>
#include <qsciapis.h>
#include <qscicommand.h>
#include <qscicommandset.h>
#include <qscidocument.h>
#include <qsciglobal.h>
#include <qscilexerbash.h>
#include <qscilexerbatch.h>
#include <qscilexercmake.h>
#include <qscilexercpp.h>
#include <qscilexercsharp.h>
#include <qscilexercss.h>
#include <qscilexercustom.h>
#include <qscilexerd.h>
#include <qscilexerdiff.h>
#include <qscilexerfortran77.h>
#include <qscilexerfortran.h>
#include <qscilexer.h>
#include <qscilexerhtml.h>
#include <qscilexeridl.h>
#include <qscilexerjava.h>
#include <qscilexerjavascript.h>
#include <qscilexerlua.h>
#include <qscilexermakefile.h>
#include <qscilexerpascal.h>
#include <qscilexerperl.h>
#include <qscilexerpostscript.h>
#include <qscilexerpov.h>
#include <qscilexerproperties.h>
#include <qscilexerpython.h>
#include <qscilexerruby.h>
#include <qscilexersql.h>
#include <qscilexertcl.h>
#include <qscilexertex.h>
#include <qscilexervhdl.h>
#include <qscilexerxml.h>
#include <qscilexeryaml.h>
#include <qscimacro.h>
#include <qsciprinter.h>
#include <qsciscintillabase.h>
#include <qsciscintilla.h>
#include <qscistyledtext.h>
#include <qscistyle.h>

#include <qvariant.h>
