#include <qwt.h>
#include <qwt_abstract_scale.h>
#include <qwt_abstract_scale_draw.h>
#include <qwt_abstract_slider.h>
#include <qwt_analog_clock.h>
#include <qwt_array.h>
#include <qwt_arrow_button.h>
#include <qwt_clipper.h>
#include <qwt_color_map.h>
#include <qwt_compass.h>
#include <qwt_compass_rose.h>
#include <qwt_counter.h>
#include <qwt_curve_fitter.h>
#include <qwt_data.h>
#include <qwt_dial.h>
#include <qwt_dial_needle.h>
#include <qwt_double_interval.h>
#include <qwt_double_range.h>
#include <qwt_double_rect.h>
#include <qwt_dyngrid_layout.h>
#include <qwt_event_pattern.h>
#include <qwt_global.h>
#include <qwt_interval_data.h>
#include <qwt_knob.h>
#include <qwt_layout_metrics.h>
#include <qwt_legend.h>
#include <qwt_legend_item.h>
#include <qwt_legend_itemmanager.h>
#include <qwt_magnifier.h>
#include <qwt_math.h>
#include <qwt_paint_buffer.h>
#include <qwt_painter.h>
#include <qwt_panner.h>
#include <qwt_picker.h>
#include <qwt_picker_machine.h>
#include <qwt_plot.h>
#include <qwt_plot_canvas.h>
#include <qwt_plot_curve.h>
#include <qwt_plot_dict.h>
#include <qwt_plot_grid.h>
#include <qwt_plot_item.h>
#include <qwt_plot_layout.h>
#include <qwt_plot_magnifier.h>
#include <qwt_plot_marker.h>
#include <qwt_plot_panner.h>
#include <qwt_plot_picker.h>
#include <qwt_plot_printfilter.h>
#include <qwt_plot_rasteritem.h>
#include <qwt_plot_rescaler.h>
#include <qwt_plot_scaleitem.h>
#include <qwt_plot_spectrogram.h>

#ifndef Q_WS_MAC    // this doesn't seem to exist on OS X
#include <qwt_plot_svgitem.h>
#endif

#include <qwt_plot_zoomer.h>
#include <qwt_polygon.h>
#include <qwt_raster_data.h>
#include <qwt_round_scale_draw.h>
#include <qwt_scale_div.h>
#include <qwt_scale_draw.h>
#include <qwt_scale_engine.h>
#include <qwt_scale_map.h>
#include <qwt_scale_widget.h>
#include <qwt_slider.h>
#include <qwt_spline.h>
#include <qwt_symbol.h>
#include <qwt_text.h>
#include <qwt_text_engine.h>
#include <qwt_text_label.h>
#include <qwt_thermo.h>
#include <qwt_valuelist.h>
#include <qwt_wheel.h>

#include <qvariant.h>
